@@ -58,6 +58,7 @@ test_that("side effect", {
     x <- 1:3 %>>% (~ x ~ side(x))
     c(x,env$x)
   }, c(1:3,2:4))
+  testthat::expect_output(1:10 %>>% "compute sum" %>>% sum, "compute sum")
 })
 
 test_that("assignment", {
@@ -109,6 +110,16 @@ test_that("assignment", {
     x <- 1:3 %>>% (. -> p) %>>% mean()
     list(x,p)
   },list(2,1:3))
+  expect_identical({
+    m <- 0
+    local({1:10 %>>% (. -> m)})
+    m
+  },0)
+  expect_identical({
+    m <- 0
+    local({1:10 %>>% (. ->> m)})
+    m
+  },1:10)
   expect_identical({
     x <- 1:3 %>>% (m ~ m + 1L -> p) %>>% mean()
     list(x,p)
@@ -182,3 +193,15 @@ test_that("scoping", {
     1:3 %>>% (function(x) mean(x + . * p))
   })(1),5)
 })
+
+test_that("printing", {
+  expect_output({
+    z <- 1:10 %>>% (? length(.)) %>>% sum
+  }, "^\\? length\\(\\.\\)\n\\[1\\] 10$")
+  expect_output({
+    z <- 1:10 %>>% ("length" ? length(.)) %>>% sum
+  }, "^\\? length\\s*\n\\[1\\] 10$")
+  expect_output({
+    z <- 1:10 %>>% "numbers" %>>% sum
+  }, "^numbers\\s*$")
+})
